# !/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import find_packages, setup

setup(
    name="prlgen",
    version="2.0.1",
    packages=find_packages(where="src"),
    install_requires=[
        # List your package's dependencies here
    ],
)
